@@ -1,6 +1,6 @@
 package IO::Interactive;
 
-use version; $VERSION = qv('0.0.6');
+use version; $VERSION = qv('0.0.1');
 
 use warnings;
 use strict;
@@ -8,7 +8,7 @@ use Carp;
 use Scalar::Util qw( openhandle );
 
 sub is_interactive {
-    my ($out_handle) = (@_, select);    # Default to default output handle
+    my ($out_handle) = (@_, \*STDOUT);    # Default to STDOUT
 
     # Not interactive if output is not to terminal...
     return 0 if not -t $out_handle;
@@ -26,19 +26,14 @@ sub is_interactive {
     }
 
     # If *ARGV isn't opened, it will be interactive if *STDIN is attached 
-    # to a terminal.
+    # to a terminal and either there are no files specified on the command line
+    # or if there are files and the first is the magic '-' file
     else {
-        return -t *STDIN;
+        return -t *STDIN && (@ARGV==0 || $ARGV[0] eq '-');
     }
 }
 
-local (*DEV_NULL, *DEV_NULL2);
-my $dev_null;
-BEGIN {
-    pipe *DEV_NULL, *DEV_NULL2
-        or die "Internal error: can't create null filehandle";
-    $dev_null = \*DEV_NULL;
-}
+open my $dev_null, '>', \do{my $dev_null};
 
 sub interactive {
     my ($out_handle) = (@_, \*STDOUT);      # Default to STDOUT
@@ -136,9 +131,10 @@ __END__
 
 IO::Interactive - Utilities for interactive I/O
 
+
 =head1 VERSION
 
-This document describes IO::Interactive version 0.0.6
+This document describes IO::Interactive version 0.0.1
 
 
 =head1 SYNOPSIS
@@ -168,17 +164,16 @@ develop interactive applications...
 
 =item C<is_interactive()>
 
-This subroutine returns true if C<*ARGV> and the currently selected
-filehandle (usually C<*STDOUT>) are connected to the terminal. The 
-test is considerably more sophisticated than:
+This subroutine returns true if C<*ARGV> and C<*STDOUT> are connected to 
+the terminal. The test is considerably more sophisticated than:
 
     -t *ARGV && -t *STDOUT
 
 as it takes into account the magic behaviour of C<*ARGV>.
 
 You can also pass C<is_interactive> a writable filehandle, in which case it
-requires that filehandle be connected to a terminal (instead of the
-currently selected).  The usual suspect here is C<*STDERR>:
+requires that filehandle be connected to a terminal (instead of C<*STDOUT>).
+The usual suspect here is C<*STDERR>:
 
     if ( is_interactive(*STDERR) ) {
         carp $warning;
@@ -244,6 +239,7 @@ Scalar::Util module.
 
 None reported.
 
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
@@ -257,7 +253,6 @@ L<http://rt.cpan.org>.
 
 Damian Conway  C<< <DCONWAY@cpan.org> >>
 
-Currently maintained by brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 LICENCE AND COPYRIGHT
 
@@ -289,5 +284,3 @@ RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
-
-=cut
